rosr Rmd template
rmd_template(..., template_name, keep_tex = TRUE, citation_package = "natbib",
md_extensions = c("-autolink_bare_uris", "-auto_identifiers"))statement_svm(...)
article_svm(...)
cv_svm(...)
syllabus_svm(...)
manuscript_svm(...)
letter_moderncv(...)
beamer_zh(...)
keep_tex, citation_package, md_extensions
Arguments passed to rmarkdown::pdf_document().
the template name.
Keep the intermediate tex file used in the conversion to PDF
The LaTeX package to process citations, natbib
or biblatex. Use none if neither package is to be used.
Markdown extensions to be added or removed from the
default definition or R Markdown. See the rmarkdown_format for
additional details.
An R Markdown output format.
statement_svm, article_svm, cv_svm, syllabus_svm, manuscript_svm are adapted from https://github.com/svmiller/svm-r-markdown-templates.